"""Global variables associated to the test suite."""

#: List of CPP variables that should be defined in config.h in order to enable this suite.
need_cpp_vars = [
"HAVE_DFT_BIGDFT"
]

#: List of keywords that are automatically added to all the tests of this suite. 
keywords = [
"WVL"
]

#: List of input files
inp_files = [
"t00.in",
"t01.in",
"t02.in",
"t03.in",
"t04.in",
"t05.in",
"t06.in",
"t07.in",
"t09.in",
"t10.in",
"t11.in",
"t12.in",
"t14.in",
"t16.in",
"t17.in",
"t18.in",
"t20.in",
"t21.in",
"t22.in",
"t23.in",
"t31.in",
"t32.in",
"t33.in",
"-t34.in",
]
